@@ -14,20 +14,30 @@
 
 import logging
 
-DEFAULT_API_URL = 'https://arweave.net'
+PUBLIC_GATEWAYS = [
+    'https://arweave.net',
+    'https://arweave.live',
+    'https://arweave-dev.everpay.io'
+]
+
+DEFAULT_API_URL = PUBLIC_GATEWAYS[0]
 
 logger = logging.getLogger(__name__)
 
 class ArweaveException(Exception):
     pass
 
-__all__ = ['Peer', 'Wallet', 'Transaction', 'arql', 'ArweaveException', 'logger', 'ArweaveTransactionException']
+__all__ = [
+    'Peer', 'Wallet', 'Transaction', 'Block',
+    'Bundle', 'DataItem', 'ANS104BundleHeader', 'ANS104DataItemHeader',
+    'arql', 'ArweaveException', 'logger', 'ArweaveTransactionException']
 
 ArweaveTransactionException = ArweaveException
 
 from .peer import Peer
 from .wallet import Wallet
 from .transaction import Transaction
+from .block import Block
 from .arweave_lib import arql
 from .bundle import Bundle, DataItem, ANS104BundleHeader, ANS104DataItemHeader
 
