@@ -341,14 +341,14 @@ class Peer(HTTPClient):
         response = self._post(block_announcement, 'block_announcement')
         return response.json()
 
-    def block(self, block):
+    def send_block(self, block):
         '''Accept a JSON-encoded block with Base64Url encoded fields.'''
-        response = self._put(block, 'block')
+        response = self._post(block, 'block')
         return response.text # OK
 
-    def block2(self, block):
+    def send_block2(self, block):
         '''Accept a binary-encoded block.'''
-        response = self._put(block, 'block2')
+        response = self._post(block, 'block2')
         return response.text # OK
 
     def wallet(self, secret):
@@ -600,7 +600,7 @@ class Peer(HTTPClient):
         if encoded_transaction_indices is not None:
             response = self._post(encoded_transaction_indices, 'block2/hash', hash, method = 'GET')
         else:
-            response = self._get(encoded_transaction_indices, 'block2/hash', hash)
+            response = self._get('block2/hash', hash)
         return response.content
 
     def block2_height(self, height, encoded_transaction_indices = None):
@@ -617,7 +617,7 @@ class Peer(HTTPClient):
         if encoded_transaction_indices is not None:
             response = self._post(encoded_transaction_indices, 'block2/height', str(height), method = 'GET')
         else:
-            response = self._get(encoded_transaction_indices, 'block2/height', str(height))
+            response = self._get('block2/height', str(height))
         return response.content
 
     def block_current(self):
@@ -630,6 +630,20 @@ class Peer(HTTPClient):
         response = self._get('current_block')
         return response.json()
 
+    def block(self, height_or_hash):
+        if type(height_or_hash) is int:
+            return self.block_height(height_or_hash)
+        elif not height_or_hash :
+            return self.block_current()
+        else:
+            return self.block_hash(height_or_hash)
+
+    def block2(self, height_or_hash):
+        if type(height_or_hash) is int:
+            return self.block2_height(height_or_hash)
+        else:
+            return self.block2_hash(height_or_hash)
+
     def tx_field(self, hash, field):
         '''
         Return a given field of the transaction specified by the transaction ID (hash).
